#[repr(C)]pub struct KeyEventInjectorInjectResponse {
pub status: KeyEventStatus,
}Fields
status: KeyEventStatusTrait Implementations
Sourceimpl Clone for KeyEventInjectorInjectResponse
impl Clone for KeyEventInjectorInjectResponse
Sourcefn clone(&self) -> KeyEventInjectorInjectResponse
fn clone(&self) -> KeyEventInjectorInjectResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for KeyEventInjectorInjectResponse
Sourceimpl<___E> Encode<KeyEventInjectorInjectResponse, ___E> for KeyEventInjectorInjectResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<KeyEventInjectorInjectResponse, ___E> for KeyEventInjectorInjectResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, KeyEventInjectorInjectResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, KeyEventInjectorInjectResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<KeyEventInjectorInjectResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<KeyEventInjectorInjectResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<KeyEventInjectorInjectResponse, ___E> for &'a KeyEventInjectorInjectResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<KeyEventInjectorInjectResponse, ___E> for &'a KeyEventInjectorInjectResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<KeyEventInjectorInjectResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<KeyEventInjectorInjectResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, KeyEventInjectorInjectResponse>, ___E> for KeyEventInjectorInjectResponsewhere
___E: Encoder + ?Sized,
KeyEventInjectorInjectResponse: Encode<KeyEventInjectorInjectResponse, ___E>,
impl<___E> EncodeOption<Box<'static, KeyEventInjectorInjectResponse>, ___E> for KeyEventInjectorInjectResponsewhere
___E: Encoder + ?Sized,
KeyEventInjectorInjectResponse: Encode<KeyEventInjectorInjectResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, KeyEventInjectorInjectResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, KeyEventInjectorInjectResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, KeyEventInjectorInjectResponse>, ___E> for &'a KeyEventInjectorInjectResponsewhere
___E: Encoder + ?Sized,
&'a KeyEventInjectorInjectResponse: Encode<KeyEventInjectorInjectResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, KeyEventInjectorInjectResponse>, ___E> for &'a KeyEventInjectorInjectResponsewhere
___E: Encoder + ?Sized,
&'a KeyEventInjectorInjectResponse: Encode<KeyEventInjectorInjectResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, KeyEventInjectorInjectResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, KeyEventInjectorInjectResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for KeyEventInjectorInjectResponse
Sourceimpl FromWire<KeyEventInjectorInjectResponse> for KeyEventInjectorInjectResponse
impl FromWire<KeyEventInjectorInjectResponse> for KeyEventInjectorInjectResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<KeyEventInjectorInjectResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<KeyEventInjectorInjectResponse, Self>
Sourcefn from_wire(wire: KeyEventInjectorInjectResponse) -> Self
fn from_wire(wire: KeyEventInjectorInjectResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<KeyEventInjectorInjectResponse> for KeyEventInjectorInjectResponse
impl FromWireRef<KeyEventInjectorInjectResponse> for KeyEventInjectorInjectResponse
Sourcefn from_wire_ref(wire: &KeyEventInjectorInjectResponse) -> Self
fn from_wire_ref(wire: &KeyEventInjectorInjectResponse) -> Self
Converts the given reference to this type.
Sourceimpl Ord for KeyEventInjectorInjectResponse
impl Ord for KeyEventInjectorInjectResponse
Sourcefn cmp(&self, other: &KeyEventInjectorInjectResponse) -> Ordering
fn cmp(&self, other: &KeyEventInjectorInjectResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for KeyEventInjectorInjectResponse
impl PartialOrd for KeyEventInjectorInjectResponse
impl StructuralPartialEq for KeyEventInjectorInjectResponse