KeyEventInjectorServerHandler

Trait KeyEventInjectorServerHandler 

pub trait KeyEventInjectorServerHandler<___T: Transport = Channel> {
    // Required method
    fn inject(
        &mut self,
        request: Request<Inject, ___T>,
        responder: Responder<Inject, ___T>,
    ) -> impl Future<Output = ()> + Send;
}
A server handler for the KeyEventInjector protocol.

See KeyEventInjector for more details.

Required Methods

fn inject( &mut self, request: Request<Inject, ___T>, responder: Responder<Inject, ___T>, ) -> impl Future<Output = ()> + Send

Inject an event into the keyboard subsystem.

Returns
  • HANDLED if the keyboard subsystem delivered the event to a consumer, and the consumer reported that it HANDLED the event
  • NOT_HANDLED if the keyboard subsystem did not deliever the event to any consumers, or no consumer reported that it HANDLED the event.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors